<?php
/**
 * Fitness Classes Sections 3
 */
return array(
	'title'      => esc_html__( 'Fitness Classes Sections 3', 'gymfinity-fse' ),
	'categories' => array( 'gymfinity-fse', 'Fitness Classes Sections 3' ),
	'content'    => '<!-- wp:group {"className":"fse-sections-03","style":{"spacing":{"padding":{"top":"var:preset|spacing|80","bottom":"var:preset|spacing|80","right":"var:preset|spacing|50","left":"var:preset|spacing|50"}},"color":{"background":"#ebefef"}},"layout":{"type":"default"}} -->
<div class="wp-block-group fse-sections-03 has-background" style="background-color:#ebefef;padding-top:var(--wp--preset--spacing--80);padding-right:var(--wp--preset--spacing--50);padding-bottom:var(--wp--preset--spacing--80);padding-left:var(--wp--preset--spacing--50)"><!-- wp:group {"layout":{"type":"constrained","contentSize":"1170px"}} -->
<div class="wp-block-group"><!-- wp:heading {"textAlign":"center","level":5,"style":{"typography":{"fontSize":"20px"},"elements":{"link":{"color":{"text":"var:preset|color|primary"}}},"spacing":{"padding":{"top":"0","bottom":"0"},"margin":{"top":"0","bottom":"0"}}},"textColor":"primary","fontFamily":"poppins"} -->
<h5 class="wp-block-heading has-text-align-center has-primary-color has-text-color has-link-color has-poppins-font-family" style="margin-top:0;margin-bottom:0;padding-top:0;padding-bottom:0;font-size:20px">Our Classes</h5>
<!-- /wp:heading -->

<!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"46px"},"elements":{"link":{"color":{"text":"#0a0a0a"}}},"color":{"text":"#0a0a0a"},"spacing":{"margin":{"top":"0","bottom":"var:preset|spacing|70"}}},"fontFamily":"oswald"} -->
<h2 class="wp-block-heading has-text-align-center has-text-color has-link-color has-oswald-font-family" style="color:#0a0a0a;margin-top:0;margin-bottom:var(--wp--preset--spacing--70);font-size:46px">Fitness Classes for Every Goal</h2>
<!-- /wp:heading -->

<!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column {"style":{"spacing":{"padding":{"top":"0","bottom":"0"},"blockGap":"0"}}} -->
<div class="wp-block-column" style="padding-top:0;padding-bottom:0"><!-- wp:image {"id":2646,"sizeSlug":"full","linkDestination":"none","style":{"border":{"radius":{"topLeft":"10px","topRight":"10px","bottomLeft":"0px","bottomRight":"0px"}}}} -->
<figure class="wp-block-image size-full has-custom-border"><img src="'.esc_url(get_template_directory_uri()).'/assets/images/classes-image01.jpg" alt="" class="wp-image-2646" style="border-top-left-radius:10px;border-top-right-radius:10px;border-bottom-left-radius:0px;border-bottom-right-radius:0px"/></figure>
<!-- /wp:image -->

<!-- wp:group {"style":{"border":{"radius":{"topLeft":"0px","topRight":"0px","bottomLeft":"10px","bottomRight":"10px"}},"spacing":{"padding":{"top":"var:preset|spacing|60","bottom":"var:preset|spacing|60"}}},"backgroundColor":"foreground","layout":{"type":"default"}} -->
<div class="wp-block-group has-foreground-background-color has-background" style="border-top-left-radius:0px;border-top-right-radius:0px;border-bottom-left-radius:10px;border-bottom-right-radius:10px;padding-top:var(--wp--preset--spacing--60);padding-bottom:var(--wp--preset--spacing--60)"><!-- wp:group {"layout":{"type":"flex","flexWrap":"nowrap"}} -->
<div class="wp-block-group"><!-- wp:image {"id":2650,"sizeSlug":"full","linkDestination":"none"} -->
<figure class="wp-block-image size-full"><img src="http://localhost/www/FSE-FreeThemes/wp-content/uploads/2024/09/gym-class-icon01.png" alt="" class="wp-image-2650"/></figure>
<!-- /wp:image -->

<!-- wp:paragraph {"style":{"typography":{"fontSize":"21px","fontStyle":"normal","fontWeight":"600","lineHeight":"1.2"}},"fontFamily":"poppins"} -->
<p class="has-poppins-font-family" style="font-size:21px;font-style:normal;font-weight:600;line-height:1.2">Weight Lifting<br>Classes</p>
<!-- /wp:paragraph --></div>
<!-- /wp:group -->

<!-- wp:paragraph -->
<p>Curabitur faucibusy tellus magoan<br>usemper nunc finibust nisi.</p>
<!-- /wp:paragraph --></div>
<!-- /wp:group --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"top":"0","bottom":"0"},"blockGap":"0"}}} -->
<div class="wp-block-column" style="padding-top:0;padding-bottom:0"><!-- wp:image {"id":2669,"sizeSlug":"full","linkDestination":"none","style":{"border":{"radius":{"topLeft":"10px","topRight":"10px","bottomLeft":"0px","bottomRight":"0px"}}}} -->
<figure class="wp-block-image size-full has-custom-border"><img src="'.esc_url(get_template_directory_uri()).'/assets/images/classes-image02.jpg" alt="" class="wp-image-2669" style="border-top-left-radius:10px;border-top-right-radius:10px;border-bottom-left-radius:0px;border-bottom-right-radius:0px"/></figure>
<!-- /wp:image -->

<!-- wp:group {"style":{"border":{"radius":{"topLeft":"0px","topRight":"0px","bottomLeft":"10px","bottomRight":"10px"}},"spacing":{"padding":{"top":"var:preset|spacing|60","bottom":"var:preset|spacing|60"}}},"backgroundColor":"foreground","layout":{"type":"default"}} -->
<div class="wp-block-group has-foreground-background-color has-background" style="border-top-left-radius:0px;border-top-right-radius:0px;border-bottom-left-radius:10px;border-bottom-right-radius:10px;padding-top:var(--wp--preset--spacing--60);padding-bottom:var(--wp--preset--spacing--60)"><!-- wp:group {"layout":{"type":"flex","flexWrap":"nowrap"}} -->
<div class="wp-block-group"><!-- wp:image {"id":2666,"sizeSlug":"full","linkDestination":"none"} -->
<figure class="wp-block-image size-full"><img src="http://localhost/www/FSE-FreeThemes/wp-content/uploads/2024/09/gym-class-icon02.png" alt="" class="wp-image-2666"/></figure>
<!-- /wp:image -->

<!-- wp:paragraph {"style":{"typography":{"fontSize":"21px","fontStyle":"normal","fontWeight":"600","lineHeight":"1.2"}},"fontFamily":"poppins"} -->
<p class="has-poppins-font-family" style="font-size:21px;font-style:normal;font-weight:600;line-height:1.2">Cardio &amp; Strenght<br>Classes</p>
<!-- /wp:paragraph --></div>
<!-- /wp:group -->

<!-- wp:paragraph -->
<p>Curabitur faucibusy tellus magoan<br>usemper nunc finibust nisi.</p>
<!-- /wp:paragraph --></div>
<!-- /wp:group --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"top":"0","bottom":"0"},"blockGap":"0"}}} -->
<div class="wp-block-column" style="padding-top:0;padding-bottom:0"><!-- wp:image {"id":2670,"sizeSlug":"full","linkDestination":"none","style":{"border":{"radius":{"topLeft":"10px","topRight":"10px","bottomLeft":"0px","bottomRight":"0px"}}}} -->
<figure class="wp-block-image size-full has-custom-border"><img src="'.esc_url(get_template_directory_uri()).'/assets/images/classes-image03.jpg" alt="" class="wp-image-2670" style="border-top-left-radius:10px;border-top-right-radius:10px;border-bottom-left-radius:0px;border-bottom-right-radius:0px"/></figure>
<!-- /wp:image -->

<!-- wp:group {"style":{"border":{"radius":{"topLeft":"0px","topRight":"0px","bottomLeft":"10px","bottomRight":"10px"}},"spacing":{"padding":{"top":"var:preset|spacing|60","bottom":"var:preset|spacing|60"}}},"backgroundColor":"foreground","layout":{"type":"default"}} -->
<div class="wp-block-group has-foreground-background-color has-background" style="border-top-left-radius:0px;border-top-right-radius:0px;border-bottom-left-radius:10px;border-bottom-right-radius:10px;padding-top:var(--wp--preset--spacing--60);padding-bottom:var(--wp--preset--spacing--60)"><!-- wp:group {"layout":{"type":"flex","flexWrap":"nowrap"}} -->
<div class="wp-block-group"><!-- wp:image {"id":2667,"sizeSlug":"full","linkDestination":"none"} -->
<figure class="wp-block-image size-full"><img src="http://localhost/www/FSE-FreeThemes/wp-content/uploads/2024/09/gym-class-icon03.png" alt="" class="wp-image-2667"/></figure>
<!-- /wp:image -->

<!-- wp:paragraph {"style":{"typography":{"fontSize":"21px","fontStyle":"normal","fontWeight":"600","lineHeight":"1.2"}},"fontFamily":"poppins"} -->
<p class="has-poppins-font-family" style="font-size:21px;font-style:normal;font-weight:600;line-height:1.2">Power Yoga<br>Classes</p>
<!-- /wp:paragraph --></div>
<!-- /wp:group -->

<!-- wp:paragraph -->
<p>Curabitur faucibusy tellus magoan<br>usemper nunc finibust nisi.</p>
<!-- /wp:paragraph --></div>
<!-- /wp:group --></div>
<!-- /wp:column --></div>
<!-- /wp:columns --></div>
<!-- /wp:group --></div>
<!-- /wp:group -->',
);