<?php
/**
 * 404 Not Found
 */
return array(
	'title'      => esc_html__( '404 Not Found', 'gymfinity-fse' ),
	'categories' => array( 'gymfinity-fse', '404' ),
	'content'    => '<!-- wp:group {"style":{"spacing":{"blockGap":"0","margin":{"top":"0","bottom":"0"},"padding":{"top":"0","bottom":"0","left":"0","right":"0"}}},"layout":{"type":"default"}} -->
<div class="wp-block-group" style="margin-top:0;margin-bottom:0;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:group {"style":{"color":{"background":"#edebeb"},"spacing":{"padding":{"top":"var:preset|spacing|70","bottom":"var:preset|spacing|70","right":"var:preset|spacing|50","left":"var:preset|spacing|50"}}},"layout":{"type":"constrained","contentSize":"1170px"}} -->
<div class="wp-block-group has-background" style="background-color:#edebeb;padding-top:var(--wp--preset--spacing--70);padding-right:var(--wp--preset--spacing--50);padding-bottom:var(--wp--preset--spacing--70);padding-left:var(--wp--preset--spacing--50)"><!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"120px"},"color":{"text":"#878e96"}}} -->
<h2 class="wp-block-heading has-text-align-center has-text-color" style="color:#878e96;font-size:120px"><strong>404</strong></h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"small"} -->
<p class="has-text-align-center has-small-font-size">This page is not found</p>
<!-- /wp:paragraph -->

<!-- wp:search {"label":"Search","showLabel":false,"width":517,"widthUnit":"px","buttonText":"Search","align":"center","textColor":"foreground"} /--></div>
<!-- /wp:group --></div>
<!-- /wp:group -->',
);

    
    
    
