/*
Theme Name: Gymfinity FSE
Theme URI: https://gracethemes.com/themes/free-health-fitness-wordpress-theme/
Author: Grace Themes
Author URI: https://gracethemes.com/
Description: The Gymfinity FSE is a free health fitness WordPress theme, as it is the best option for gym centers, yoga businesses, and fitness-related businesses. It helps to create a fantastic website for your gym business. It is not only appealing and it offers a professional and modern architecture suiting the needs of your gym or athletics business. This theme is extremely appealing and compatible with the latest version of WordPress. The Gymfinity FSE theme has a very impressive homepage. This Free health fitness WordPress theme is a full-site website editing theme, and there is no need for coding knowledge to operate it. This is an SEO-optimized WordPress theme. This WordPress theme is compatible with multiple devices. It means it does not matter whether you have a PC, a tablet, a laptop, a smartphone, or any other smart device, you can always use this theme. This theme has proudly qualified for the mobile-friendly test conducted by the tech-giant Google. This is a cross-device compatible theme and is also cross-browser compatible. Demo: https://gracethemesdemo.com/gymfinity/

Version: 1.0
License: GNU General Public License version 2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Text Domain: gymfinity-fse
Requires PHP:  5.6
Tested up to: 6.6
Tags:blog, news, one-column, two-columns, right-sidebar, block-styles, custom-colors, editor-style, custom-background, custom-menu, featured-images, template-editing, full-site-editing, block-patterns,  threaded-comments, wide-blocks, translation-ready
Gymfinity  FSE WordPress Theme has been created by Grace Themes(gracethemes.com), 2024.
Gymfinity  FSE WordPress Theme is released under the terms of GNU GPL
*/
body.page-template-front .site-main-header {  
	width:100%; 
	z-index:999;	
	background:transparent !important; 
	position: absolute !important;
}
.site-main-header{  
	position:relative;
	background-color:#262325; 
}
.clear{ clear:both; }

/*dropdown menu background color*/
.wp-block-navigation .has-child .wp-block-navigation__submenu-container{ 
	background-color:#2d2a2b;
}
.wp-block-navigation .has-child .wp-block-navigation__submenu-container li{ 
	padding:5px 0; 
	border-bottom:1px solid #534e50 !important;
}
.wp-block-navigation__submenu-container.wp-block-navigation-submenu{ 
	padding-top:30px !important
}
.wp-block-navigation__submenu-container.wp-block-navigation-submenu li ul{ 
	padding-top:0 !important; 
	left:100% !important; 
	right:auto !important;
}

.logo {  
    padding:20px 50px 20px 0px !important;
    position: relative;
	border-right:2px solid #219451;
}
.header_right_menu{
	background-color:rgba(175,175,175, 0.2); 
	position:relative; 
	border-left:2px solid #219451;
	padding:35px !important; 
}

.wrap-4-box{ 
	margin-bottom:-75px !important;
}
.gym-services-25{ 
	position:relative;
}
.gym-services-25 .gym-image-title{ 
	position:absolute; 
	bottom:35px; 
	left:0; 
	right:0;
}


/* = Sidebar CSS
----------------------------------------------- */
.st-widgetBX ul.wp-block-latest-posts li{ 
	margin-bottom:20px; 
	min-height:80px;
}
.st-widgetBX ul.wp-block-latest-posts li a.wp-block-latest-posts__post-title{ 
	margin-bottom:5px !important; 
	display:block; 
	line-height:20px;
}


/* = Blog page Design CSS
----------------------------------------------- */
ul.blog-list-style{ 
	margin:0; 
	padding:0; 
}
ul.blog-list-style li{ 
	margin-bottom:25px; 
	padding:30px;
	border-radius:5px; 
	display:flow-root; 
	box-shadow:0 0 30px rgb(193 193 193/30%);
	
}
ul.blog-list-style li .blog-thumbx{ 
	margin:0 35px 20px 0;
}
ul.blog-list-style li a.wp-block-post-excerpt__more-link{ 
	padding:10px 20px; border-radius:10px
}

ul.blog-list-style li .blog-thumbx.wp-block-post-featured-image a,
ul.blog-list-style li .blog-thumbx.wp-block-post-featured-image img{ 
	height:auto;
}
.wp-block-group.sidebar-blog .st-widgetBX{ 
	box-shadow:0 0 30px rgb(193 193 193/30%);
}

.wp-block-group.PostStyle-1{ 
	padding:30px;
	border-radius:5px; 
	display:flow-root; 
	box-shadow:0 0 30px rgb(193 193 193/30%);
}
.wp-block-column.fse-page-layout{
	padding:30px;
	border-radius:5px; 
	display:flow-root; 
	box-shadow:0 0 30px rgb(193 193 193/30%);
}


/* = Contact Form 7 CSS
----------------------------------------------- */
.wpcf7{ 
	margin:30px 0 0;padding:0;
}
.wpcf7 input[type="text"], 
.wpcf7 input[type="tel"], 
.wpcf7 input[type="email"]{ 
	width:40%;
	border:1px solid #cccccc;
	box-shadow:inset 1px 1px 2px #ccc;
	color:#797979;
	margin-bottom:0;
	height:40px;
	padding:0 15px;
}	
.wpcf7 textarea{
	color:#797979;
	margin-bottom:25px;
	border:1px solid #cccccc;
	box-shadow:inset 1px 1px 2px #ccc;
	padding:10px;
	width:60%;
	height:160px;
	font-size:12px;
}
.wpcf7 input[type="submit"]{
	border-radius:40px;
	font-weight:600;
	font-size:16px;
	cursor:pointer;
	background-color:#60c19f;
	padding:20px 40px;
	color:#ffffff;
	width:auto;
	border:none;
	text-transform:uppercase;
}
.wpcf7 input[type="submit"]:hover{
	background-color:#101010;
}

/* = Footer CSS
----------------------------------------------- */
.site-footer{ 
	position:relative;
}
.site-footer h3.wp-block-heading{ 
	position:relative; 
}

ul.fs-footer-post{ 
	margin:0; 
	padding:0;
}
ul.fs-footer-post li{ 
	list-style:none; 
	margin-bottom:30px;
}
ul.fs-footer-post li .wp-block-latest-posts__featured-image{ 
	margin-top:6px;
}
ul.fs-footer-post li .wp-block-latest-posts__featured-image img{ 
	border-radius:10px;
}
ul.fs-footer-post li .wp-block-latest-posts__post-title{ 
	margin-bottom:15px; 
	display:block; 
	line-height:22px;
}
ul.fs-footer-post li .wp-block-latest-posts__post-title:hover{ 
	color:#8cc73e;
}
footer.wp-block-template-part{ 
	margin-block-start:0 !important
}

.Footer-QuickLinks{ 
	list-style:none !important; 
	padding:0 !important;
}
.Footer-QuickLinks li{ 
	list-style:none !important; 
	padding:5px 0 5px 0 !important;
}
.Footer-QuickLinks li a:hover{ 
	text-decoration:none; 
}
.footer-latest-news li{ 
	margin-bottom:10px;
}