<?php
/**
 * Services Sections 1
 */
return array(
	'title'      => esc_html__( 'Sections 1 What We Offer', 'gymfinity-fse' ),
	'categories' => array( 'gymfinity-fse', 'Sections 1 What We Offer' ),
	'content'    => '<!-- wp:group {"className":"fse-sections-01","style":{"spacing":{"padding":{"top":"var:preset|spacing|80","bottom":"0","left":"var:preset|spacing|50","right":"var:preset|spacing|50"}},"color":{"background":"#ffe274"}},"layout":{"type":"default"}} -->
<div class="wp-block-group fse-sections-01 has-background" style="background-color:#ffe274;padding-top:var(--wp--preset--spacing--80);padding-right:var(--wp--preset--spacing--50);padding-bottom:0;padding-left:var(--wp--preset--spacing--50)"><!-- wp:group {"layout":{"type":"constrained","contentSize":"1170px"}} -->
<div class="wp-block-group"><!-- wp:columns {"className":"wrap-4-box"} -->
<div class="wp-block-columns wrap-4-box"><!-- wp:column {"className":"gym-services-25"} -->
<div class="wp-block-column gym-services-25"><!-- wp:cover {"url":"'.esc_url(get_template_directory_uri()).'/assets/images/gym-services-01.jpg","id":2571,"dimRatio":0,"customOverlayColor":"#60553e","isUserOverlayColor":true,"minHeight":370,"layout":{"type":"constrained"}} -->
<div class="wp-block-cover" style="min-height:370px"><span aria-hidden="true" class="wp-block-cover__background has-background-dim-0 has-background-dim" style="background-color:#60553e"></span><img class="wp-block-cover__image-background wp-image-2571" alt="" src="'.esc_url(get_template_directory_uri()).'/assets/images/gym-services-01.jpg" data-object-fit="cover"/><div class="wp-block-cover__inner-container"><!-- wp:heading {"textAlign":"center","className":"gym-image-title","style":{"typography":{"fontSize":"45px","textTransform":"uppercase","fontStyle":"normal","fontWeight":"500"},"elements":{"link":{"color":{"text":"var:preset|color|foreground"}}}},"textColor":"foreground","fontFamily":"oswald"} -->
<h2 class="wp-block-heading has-text-align-center gym-image-title has-foreground-color has-text-color has-link-color has-oswald-font-family" style="font-size:45px;font-style:normal;font-weight:500;text-transform:uppercase"><a href="#">Yoga</a></h2>
<!-- /wp:heading --></div></div>
<!-- /wp:cover --></div>
<!-- /wp:column -->

<!-- wp:column {"className":"gym-services-25"} -->
<div class="wp-block-column gym-services-25"><!-- wp:cover {"url":"'.esc_url(get_template_directory_uri()).'/assets/images/gym-services-02.jpg","id":2592,"dimRatio":0,"customOverlayColor":"#60553e","isUserOverlayColor":true,"minHeight":370,"layout":{"type":"constrained"}} -->
<div class="wp-block-cover" style="min-height:370px"><span aria-hidden="true" class="wp-block-cover__background has-background-dim-0 has-background-dim" style="background-color:#60553e"></span><img class="wp-block-cover__image-background wp-image-2592" alt="" src="'.esc_url(get_template_directory_uri()).'/assets/images/gym-services-02.jpg" data-object-fit="cover"/><div class="wp-block-cover__inner-container"><!-- wp:heading {"textAlign":"center","className":"gym-image-title","style":{"typography":{"fontSize":"45px","textTransform":"uppercase","fontStyle":"normal","fontWeight":"500"},"elements":{"link":{"color":{"text":"var:preset|color|foreground"}}}},"textColor":"foreground","fontFamily":"oswald"} -->
<h2 class="wp-block-heading has-text-align-center gym-image-title has-foreground-color has-text-color has-link-color has-oswald-font-family" style="font-size:45px;font-style:normal;font-weight:500;text-transform:uppercase"><a href="#">Crossfit</a></h2>
<!-- /wp:heading --></div></div>
<!-- /wp:cover --></div>
<!-- /wp:column -->

<!-- wp:column {"className":"gym-services-25"} -->
<div class="wp-block-column gym-services-25"><!-- wp:cover {"url":"'.esc_url(get_template_directory_uri()).'/assets/images/gym-services-03.jpg","id":2593,"dimRatio":0,"customOverlayColor":"#60553e","isUserOverlayColor":true,"minHeight":370,"layout":{"type":"constrained"}} -->
<div class="wp-block-cover" style="min-height:370px"><span aria-hidden="true" class="wp-block-cover__background has-background-dim-0 has-background-dim" style="background-color:#60553e"></span><img class="wp-block-cover__image-background wp-image-2593" alt="" src="'.esc_url(get_template_directory_uri()).'/assets/images/gym-services-03.jpg" data-object-fit="cover"/><div class="wp-block-cover__inner-container"><!-- wp:heading {"textAlign":"center","className":"gym-image-title","style":{"typography":{"fontSize":"45px","textTransform":"uppercase","fontStyle":"normal","fontWeight":"500"},"elements":{"link":{"color":{"text":"var:preset|color|foreground"}}}},"textColor":"foreground","fontFamily":"oswald"} -->
<h2 class="wp-block-heading has-text-align-center gym-image-title has-foreground-color has-text-color has-link-color has-oswald-font-family" style="font-size:45px;font-style:normal;font-weight:500;text-transform:uppercase"><a href="#">Fitness</a></h2>
<!-- /wp:heading --></div></div>
<!-- /wp:cover --></div>
<!-- /wp:column -->

<!-- wp:column {"className":"gym-services-25"} -->
<div class="wp-block-column gym-services-25"><!-- wp:cover {"url":"'.esc_url(get_template_directory_uri()).'/assets/images/gym-services-04.jpg","id":2594,"dimRatio":0,"customOverlayColor":"#60553e","isUserOverlayColor":true,"minHeight":370,"layout":{"type":"constrained"}} -->
<div class="wp-block-cover" style="min-height:370px"><span aria-hidden="true" class="wp-block-cover__background has-background-dim-0 has-background-dim" style="background-color:#60553e"></span><img class="wp-block-cover__image-background wp-image-2594" alt="" src="'.esc_url(get_template_directory_uri()).'/assets/images/gym-services-04.jpg" data-object-fit="cover"/><div class="wp-block-cover__inner-container"><!-- wp:heading {"textAlign":"center","className":"gym-image-title","style":{"typography":{"fontSize":"45px","textTransform":"uppercase","fontStyle":"normal","fontWeight":"500"},"elements":{"link":{"color":{"text":"var:preset|color|foreground"}}}},"textColor":"foreground","fontFamily":"oswald"} -->
<h2 class="wp-block-heading has-text-align-center gym-image-title has-foreground-color has-text-color has-link-color has-oswald-font-family" style="font-size:45px;font-style:normal;font-weight:500;text-transform:uppercase"><a href="#">aerobics</a></h2>
<!-- /wp:heading --></div></div>
<!-- /wp:cover --></div>
<!-- /wp:column --></div>
<!-- /wp:columns --></div>
<!-- /wp:group --></div>
<!-- /wp:group -->',
);