<?php 
/**
 * Default Header Banner
 */
return array(
	'title'      => esc_html__( 'Header Banner', 'gymfinity-fse' ),
	'categories' => array( 'gymfinity-fse', 'Header Banner' ),
	'content'    => '<!-- wp:group {"style":{"spacing":{"padding":{"top":"0","right":"0","bottom":"0","left":"0"},"blockGap":"0","margin":{"top":"0","bottom":"0"}},"dimensions":{"minHeight":"0px"}},"layout":{"type":"default"}} -->
<div class="wp-block-group" style="min-height:0px;margin-top:0;margin-bottom:0;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:cover {"url":"'.esc_url(get_template_directory_uri()).'/assets/images/header-banner.jpg","id":20,"dimRatio":0,"minHeight":690,"className":"hdrbanner-BX","style":{"spacing":{"padding":{"top":"var:preset|spacing|50","right":"var:preset|spacing|50","bottom":"var:preset|spacing|50","left":"var:preset|spacing|50"},"margin":{"top":"0","bottom":"0"},"blockGap":"0"}}} -->
<div class="wp-block-cover hdrbanner-BX" style="margin-top:0;margin-bottom:0;padding-top:var(--wp--preset--spacing--50);padding-right:var(--wp--preset--spacing--50);padding-bottom:var(--wp--preset--spacing--50);padding-left:var(--wp--preset--spacing--50);min-height:690px"><span aria-hidden="true" class="wp-block-cover__background has-background-dim-0 has-background-dim"></span><img class="wp-block-cover__image-background wp-image-20" alt="" src="'.esc_url(get_template_directory_uri()).'/assets/images/header-banner.jpg" data-object-fit="cover"/><div class="wp-block-cover__inner-container"><!-- wp:group {"className":"bannerInfo","style":{"spacing":{"padding":{"top":"0","right":"0","bottom":"0","left":"0"},"blockGap":"0","margin":{"top":"0","bottom":"0"}}},"layout":{"type":"constrained","contentSize":"1170px"}} -->
<div class="wp-block-group bannerInfo" style="margin-top:0;margin-bottom:0;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:heading {"textAlign":"left","level":5,"style":{"typography":{"fontSize":"20px","textTransform":"none","fontStyle":"normal","fontWeight":"500","lineHeight":"1.1"},"spacing":{"margin":{"top":"var:preset|spacing|70","bottom":"var:preset|spacing|40"}}},"textColor":"primary","fontFamily":"poppins"} -->
<h5 class="wp-block-heading has-text-align-left has-primary-color has-text-color has-poppins-font-family" style="margin-top:var(--wp--preset--spacing--70);margin-bottom:var(--wp--preset--spacing--40);font-size:20px;font-style:normal;font-weight:500;line-height:1.1;text-transform:none">Perfect Trainers</h5>
<!-- /wp:heading -->

<!-- wp:heading {"textAlign":"left","style":{"typography":{"fontSize":"50px","textTransform":"none","fontStyle":"normal","fontWeight":"600","lineHeight":"1.1"},"spacing":{"margin":{"bottom":"var:preset|spacing|50"}}},"textColor":"foreground","fontFamily":"oswald"} -->
<h2 class="wp-block-heading has-text-align-left has-foreground-color has-text-color has-oswald-font-family" style="margin-bottom:var(--wp--preset--spacing--50);font-size:50px;font-style:normal;font-weight:600;line-height:1.1;text-transform:none">We Always Focus on<br>Your Health</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"style":{"typography":{"fontSize":"17px"},"spacing":{"margin":{"top":"0","bottom":"var:preset|spacing|60"}}}} -->
<p style="margin-top:0;margin-bottom:var(--wp--preset--spacing--60);font-size:17px">Nunc hendrerit tellus plac magna tincidunt,<br>sed laoreet metus faucibus.</p>
<!-- /wp:paragraph -->

<!-- wp:buttons {"style":{"spacing":{"blockGap":"0"}},"layout":{"type":"flex","justifyContent":"left"}} -->
<div class="wp-block-buttons"><!-- wp:button {"textAlign":"center","backgroundColor":"primary","textColor":"foreground","className":"is-style-fill","style":{"typography":{"fontSize":"17px","fontStyle":"normal","fontWeight":"500"},"spacing":{"padding":{"left":"var:preset|spacing|60","right":"var:preset|spacing|60","top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"border":{"radius":"0px"}},"fontFamily":"poppins"} -->
<div class="wp-block-button has-custom-font-size is-style-fill has-poppins-font-family" style="font-size:17px;font-style:normal;font-weight:500"><a class="wp-block-button__link has-foreground-color has-primary-background-color has-text-color has-background has-text-align-center wp-element-button" href="#" style="border-radius:0px;padding-top:var(--wp--preset--spacing--40);padding-right:var(--wp--preset--spacing--60);padding-bottom:var(--wp--preset--spacing--40);padding-left:var(--wp--preset--spacing--60)">Learn More</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:group --></div></div>
<!-- /wp:cover --></div>
<!-- /wp:group -->',
);