<!-- wp:template-part {"slug":"header","tagName":"header"} /-->
<!-- wp:group {"tagName":"main","style":{"spacing":{"margin":{"top":"0","bottom":"0"},"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"0"}},"className":"main-home-page","layout":{"type":"default"}} -->
 <main class="wp-block-group main-home-page" style="margin-top:0;margin-bottom:0;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0">
     <!-- wp:pattern {"slug":"gymfinity-fse/header-banner"} /-->
     <!-- wp:pattern {"slug":"gymfinity-fse/section1"} /-->
     <!-- wp:pattern {"slug":"gymfinity-fse/section2"} /-->
     <!-- wp:pattern {"slug":"gymfinity-fse/section3"} /-->
 </main>
<!-- /wp:group -->
<!-- wp:template-part {"slug":"footer","tagName":"footer"} /-->