<?php 
/**
 * Welcome to Fitness Club Sections 2
 */
return array(
	'title'      => esc_html__( 'Welcome to Fitness Club Sections 2', 'gymfinity-fse' ),
	'categories' => array( 'gymfinity-fse', 'Welcome to Fitness Club Sections 2' ),
	'content'    => '<!-- wp:group {"className":"fse-sections-02","style":{"spacing":{"padding":{"top":"10rem","bottom":"var:preset|spacing|80","left":"var:preset|spacing|50","right":"var:preset|spacing|50"}}},"backgroundColor":"foreground","layout":{"type":"default"}} -->
<div class="wp-block-group fse-sections-02 has-foreground-background-color has-background" style="padding-top:10rem;padding-right:var(--wp--preset--spacing--50);padding-bottom:var(--wp--preset--spacing--80);padding-left:var(--wp--preset--spacing--50)"><!-- wp:group {"layout":{"type":"constrained","contentSize":"1170px"}} -->
<div class="wp-block-group"><!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column {"width":"45%","className":"welcome-left-part"} -->
<div class="wp-block-column welcome-left-part" style="flex-basis:45%"><!-- wp:image {"id":2716,"sizeSlug":"full","linkDestination":"none"} -->
<figure class="wp-block-image size-full"><img src="'.esc_url(get_template_directory_uri()).'/assets/images/welcome-gym-image.jpg" alt="" class="wp-image-2716"/></figure>
<!-- /wp:image --></div>
<!-- /wp:column -->

<!-- wp:column {"width":"5%"} -->
<div class="wp-block-column" style="flex-basis:5%"></div>
<!-- /wp:column -->

<!-- wp:column {"width":"50%","className":"welcome-right-50","style":{"spacing":{"blockGap":"0","padding":{"right":"0","left":"0","top":"0","bottom":"0"}}}} -->
<div class="wp-block-column welcome-right-50" style="padding-top:0;padding-right:0;padding-bottom:0;padding-left:0;flex-basis:50%"><!-- wp:heading {"level":4,"style":{"typography":{"lineHeight":"1.2","fontStyle":"normal","fontWeight":"600","fontSize":"18px"},"spacing":{"margin":{"bottom":"var:preset|spacing|40"}}},"textColor":"primary","fontFamily":"poppins"} -->
<h4 class="wp-block-heading has-primary-color has-text-color has-poppins-font-family" style="margin-bottom:var(--wp--preset--spacing--40);font-size:18px;font-style:normal;font-weight:600;line-height:1.2">Welcome to Fitness Club</h4>
<!-- /wp:heading -->

<!-- wp:heading {"className":"About-head","style":{"typography":{"fontSize":"46px","lineHeight":"1.0","fontStyle":"normal","fontWeight":"600"},"spacing":{"margin":{"bottom":"var:preset|spacing|60"}},"color":{"text":"#0a0a0a"}},"fontFamily":"oswald"} -->
<h2 class="wp-block-heading About-head has-text-color has-oswald-font-family" style="color:#0a0a0a;margin-bottom:var(--wp--preset--spacing--60);font-size:46px;font-style:normal;font-weight:600;line-height:1.0">We Can Give A Shape Of<br>Your Body Here!</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"style":{"spacing":{"margin":{"bottom":"var:preset|spacing|60"}},"typography":{"lineHeight":"1.7","fontSize":"17px"}},"textColor":"body-text","fontFamily":"poppins"} -->
<p class="has-body-text-color has-text-color has-poppins-font-family" style="margin-bottom:var(--wp--preset--spacing--60);font-size:17px;line-height:1.7">Nunc hendrerit tellus plac magna tincidunt, sed laoreet metus faucibus. Aenean eu sollicitudin augue. Nunc hendrerit feugiat semper. In tristique dictum ipsum a iaculis.</p>
<!-- /wp:paragraph -->

<!-- wp:separator {"className":"is-style-wide","style":{"color":{"background":"#e9e9e9"}}} -->
<hr class="wp-block-separator has-text-color has-alpha-channel-opacity has-background is-style-wide" style="background-color:#e9e9e9;color:#e9e9e9"/>
<!-- /wp:separator -->

<!-- wp:group {"style":{"spacing":{"margin":{"top":"var:preset|spacing|70","bottom":"0"}}},"layout":{"type":"constrained"}} -->
<div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--70);margin-bottom:0"><!-- wp:columns {"style":{"spacing":{"padding":{"top":"0","bottom":"0","left":"0","right":"0"},"margin":{"top":"0","bottom":"0"},"blockGap":{"top":"0","left":"var:preset|spacing|40"}}}} -->
<div class="wp-block-columns" style="margin-top:0;margin-bottom:0;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:column {"width":"70%","style":{"spacing":{"padding":{"top":"0","bottom":"0","left":"0","right":"0"},"blockGap":"0"}}} -->
<div class="wp-block-column" style="padding-top:0;padding-right:0;padding-bottom:0;padding-left:0;flex-basis:70%"><!-- wp:group {"style":{"spacing":{"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"var:preset|spacing|40","margin":{"bottom":"var:preset|spacing|60"}}},"layout":{"type":"flex","flexWrap":"nowrap","justifyContent":"left","orientation":"horizontal","verticalAlignment":"top"}} -->
<div class="wp-block-group" style="margin-bottom:var(--wp--preset--spacing--60);padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:group {"layout":{"type":"constrained"}} -->
<div class="wp-block-group"><!-- wp:image {"id":2605,"sizeSlug":"full","linkDestination":"none"} -->
<figure class="wp-block-image size-full"><img src="'.esc_url(get_template_directory_uri()).'/assets/images/gym-icon01.png" alt="" class="wp-image-2605"/></figure>
<!-- /wp:image --></div>
<!-- /wp:group -->

<!-- wp:group {"layout":{"type":"constrained"}} -->
<div class="wp-block-group"><!-- wp:heading {"level":4,"style":{"typography":{"fontSize":"19px","fontStyle":"normal","fontWeight":"600"},"spacing":{"margin":{"top":"0","bottom":"0","left":"0","right":"0"}}},"fontFamily":"poppins"} -->
<h4 class="wp-block-heading has-poppins-font-family" style="margin-top:0;margin-right:0;margin-bottom:0;margin-left:0;font-size:19px;font-style:normal;font-weight:600">Modern Equipment</h4>
<!-- /wp:heading -->

<!-- wp:paragraph {"style":{"typography":{"fontSize":"17px"},"spacing":{"margin":{"top":"var:preset|spacing|20","bottom":"var:preset|spacing|20"}}},"fontFamily":"poppins"} -->
<p class="has-poppins-font-family" style="margin-top:var(--wp--preset--spacing--20);margin-bottom:var(--wp--preset--spacing--20);font-size:17px">Curabitur faucibusy tellus<br>usemper nunc finibus</p>
<!-- /wp:paragraph --></div>
<!-- /wp:group --></div>
<!-- /wp:group -->

<!-- wp:group {"style":{"spacing":{"margin":{"top":"0","bottom":"0"},"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"var:preset|spacing|40"}},"layout":{"type":"flex","flexWrap":"nowrap","justifyContent":"left","orientation":"horizontal","verticalAlignment":"top"}} -->
<div class="wp-block-group" style="margin-top:0;margin-bottom:0;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:group {"layout":{"type":"constrained"}} -->
<div class="wp-block-group"><!-- wp:image {"id":2624,"sizeSlug":"full","linkDestination":"none"} -->
<figure class="wp-block-image size-full"><img src="'.esc_url(get_template_directory_uri()).'/assets/images/gym-icon02.png" alt="" class="wp-image-2624"/></figure>
<!-- /wp:image --></div>
<!-- /wp:group -->

<!-- wp:group {"layout":{"type":"constrained"}} -->
<div class="wp-block-group"><!-- wp:heading {"level":4,"style":{"typography":{"fontSize":"19px","fontStyle":"normal","fontWeight":"600"},"spacing":{"margin":{"top":"0","bottom":"0"}}},"fontFamily":"poppins"} -->
<h4 class="wp-block-heading has-poppins-font-family" style="margin-top:0;margin-bottom:0;font-size:19px;font-style:normal;font-weight:600">Body Fitness</h4>
<!-- /wp:heading -->

<!-- wp:paragraph {"style":{"typography":{"fontSize":"17px"},"spacing":{"margin":{"top":"var:preset|spacing|30","bottom":"var:preset|spacing|30"}}},"fontFamily":"poppins"} -->
<p class="has-poppins-font-family" style="margin-top:var(--wp--preset--spacing--30);margin-bottom:var(--wp--preset--spacing--30);font-size:17px">Curabitur faucibusy tellus<br>usemper nunc finibus</p>
<!-- /wp:paragraph --></div>
<!-- /wp:group --></div>
<!-- /wp:group --></div>
<!-- /wp:column -->

<!-- wp:column {"width":"30%","style":{"spacing":{"blockGap":"0","padding":{"right":"0","left":"0","top":"0","bottom":"0"}}}} -->
<div class="wp-block-column" style="padding-top:0;padding-right:0;padding-bottom:0;padding-left:0;flex-basis:30%"><!-- wp:group {"style":{"color":{"background":"#ffe274"},"border":{"radius":"10px"},"spacing":{"padding":{"top":"var:preset|spacing|50","bottom":"var:preset|spacing|50","left":"var:preset|spacing|50","right":"var:preset|spacing|50"}}},"layout":{"type":"constrained"}} -->
<div class="wp-block-group has-background" style="border-radius:10px;background-color:#ffe274;padding-top:var(--wp--preset--spacing--50);padding-right:var(--wp--preset--spacing--50);padding-bottom:var(--wp--preset--spacing--50);padding-left:var(--wp--preset--spacing--50)"><!-- wp:heading {"style":{"typography":{"fontSize":"60px"},"spacing":{"margin":{"top":"0","bottom":"0","left":"0","right":"0"}}},"fontFamily":"oswald"} -->
<h2 class="wp-block-heading has-oswald-font-family" style="margin-top:0;margin-right:0;margin-bottom:0;margin-left:0;font-size:60px">20+</h2>
<!-- /wp:heading -->

<!-- wp:paragraph -->
<p>Years<br>Experience</p>
<!-- /wp:paragraph --></div>
<!-- /wp:group --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->

<!-- wp:buttons {"style":{"spacing":{"margin":{"top":"var:preset|spacing|60"}}}} -->
<div class="wp-block-buttons" style="margin-top:var(--wp--preset--spacing--60)"><!-- wp:button {"backgroundColor":"primary","style":{"border":{"width":"0px","style":"none","radius":"0px"},"typography":{"fontSize":"15px"},"spacing":{"padding":{"left":"var:preset|spacing|60","right":"var:preset|spacing|60","top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}}}} -->
<div class="wp-block-button has-custom-font-size" style="font-size:15px"><a class="wp-block-button__link has-primary-background-color has-background wp-element-button" href="#" style="border-style:none;border-width:0px;border-radius:0px;padding-top:var(--wp--preset--spacing--40);padding-right:var(--wp--preset--spacing--60);padding-bottom:var(--wp--preset--spacing--40);padding-left:var(--wp--preset--spacing--60)">Learn More</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:group --></div>
<!-- /wp:column --></div>
<!-- /wp:columns --></div>
<!-- /wp:group --></div>
<!-- /wp:group -->',
);